.. role:: hidden
    :class: hidden-section


botorch.optim
========================================================
.. automodule:: botorch.optim


Optimization
-------------------------------------------

Acquisition Function Optimization
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.optim.optimize
    :members:

Model Fitting Optimization
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.optim.fit
    :members:
    :exclude-members: OptimizationIteration

Initialization Helpers
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.optim.initializers
    :members:

Stopping Criteria
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.optim.stopping
    :members:


Utilities
-------------------------------------------

Numpy - Torch Conversion Tools
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.optim.numpy_converter
    :members:

Parameter Constraint Utilities
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.optim.parameter_constraints
    :members:

General Optimization Utilities
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.optim.utils
    :members:
